@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    importcertificatefromfilecommand.h
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
 
@@ -39,5 +37,3 @@ private:
     inline const Private *d_func() const;
 };
 }
-
-
