@@ -23,8 +23,8 @@ extern QElapsedTimer startupTimer;
 #define STARTUP_TRACE qCDebug(KLEOPATRA_LOG) << "Startup timing:" << startupTimer.elapsed() << "ms:" << SRCNAME << __func__ << __LINE__;
 
 class MainWindow;
-class SysTrayIcon;
 class QSettings;
+class QTemporaryDir;
 
 class KleopatraApplication : public QApplication
 {
@@ -86,6 +86,9 @@ public:
     void setDistributionSettings(const std::shared_ptr<QSettings> &settings);
     std::shared_ptr<QSettings> distributionSettings() const;
 
+    // Creates a temporary directory that's removed when the application exits
+    std::weak_ptr<const QTemporaryDir> createTemporaryDirectory();
+
 public Q_SLOTS:
     void openOrRaiseMainWindow();
     void openOrRaiseSmartCardWindow();
