@@ -12,7 +12,6 @@
 
 class QAction;
 class QLabel;
-class QObject;
 class QString;
 
 namespace Kleo
@@ -96,4 +95,6 @@ private:
 
     std::vector<QPointer<QLabel>> mLabels;
 };
+
+void installAccessibleEventLogger();
 }
